﻿using System;
using System.Text;
using System.Drawing;
using System.Windows.Forms;
using System.Xml.Serialization;

namespace plexdata.CharacterLookup
{
    [Serializable]
    public class ApplicationSettings
    {
        public ApplicationSettings()
            : base()
        {
            this.LoadDefaults();
        }

        #region Settings properties definition.

        private object inputType;
        private CheckState useUpperCases;
        private CheckState useSystemEncodings;
        private CheckState characterMapping;
        private CheckState showAsTable;
        private string encodingName;
        private Point location;
        private Size size;

        #endregion // Settings properties definition.

        #region Access to serializable properties.

        public CheckState UseUpperCases
        {
            get { return this.useUpperCases; }
            set { this.useUpperCases = value; }
        }

        public CheckState UseSystemEncodings
        {
            get { return this.useSystemEncodings; }
            set { this.useSystemEncodings = value; }
        }

        public CheckState CharacterMapping
        {
            get { return this.characterMapping; }
            set { this.characterMapping = value; }
        }

        public CheckState ShowAsTable
        {
            get { return this.showAsTable; }
            set { this.showAsTable = value; }
        }

        public String EncodingName
        {
            get { return this.encodingName; }
            set { this.encodingName = value; }
        }

        public object InputType
        {
            get { return this.inputType; }
            set { this.inputType = value; }
        }

        public Point Location
        {
            get { return this.location; }
            set { this.location = value; }
        }

        public Size Size
        {
            get { return this.size; }
            set { this.size = value; }
        }

        #endregion // Access to serializable properties.

        #region Access to non-serializable properties.
        
        [XmlIgnore]
        public Encoding Encoding
        {
            get
            {
                try
                {
                    return Encoding.GetEncoding(this.encodingName);
                }
                catch
                {
                    return Encoding.Default;
                }
            }
            set
            {
                if (value != null)
                {
                    this.encodingName = value.WebName;
                }
                else
                {
                    this.encodingName = Encoding.Default.WebName;
                }
            }
        }

        #endregion // Access to non-serializable properties.

        public void LoadDefaults()
        {
            this.inputType = null;
            this.useUpperCases = CheckState.Checked;
            this.useSystemEncodings = CheckState.Unchecked;
            this.characterMapping = CheckState.Indeterminate;
            this.showAsTable = CheckState.Checked;
            this.encodingName = Encoding.Default.WebName;
            this.location = new Point(50, 50);
            this.size = new Size(100, 100);
        }
    }
}
